@@ -1,4 +1,4 @@
-# Copyright (c) 2005
+# Copyright (c) 2007
 # 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 # 
 # This file is part of PyQt.
@@ -41,7 +41,7 @@ except:
     print "SIP v3.9 or later installed."
     sys.exit(1)
 
-config = sipconfig.SIPConfig("PyQt 3.17")
+config = sipconfig.SIPConfig("PyQt 3.17.3")
 
 
 # Initialise the globals.
