@@ -1,6 +1,6 @@
 # This script generates the PyQt configuration and generates the Makefiles.
 #
-# Copyright (c) 2005
+# Copyright (c) 2007
 # 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 # 
 # This file is part of PyQt.
@@ -32,10 +32,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x031000
-pyqt_version_str = "3.16"
+pyqt_version = 0x031103
+pyqt_version_str = "3.17.3"
 
-sip_min_version = 0x040400
+sip_min_version = 0x040600
 
 
 # Try and find a Qt installation to use as the default.
@@ -120,7 +120,7 @@ def usage(rcode = 2):
     print "  -q dir  the root directory of the Qt installation [default %s]" % def_qt_dir
     print "  -r      generate code with tracing enabled [default disabled]"
     print "  -s      QScintilla is a static library and not a DLL (Windows only)"
-    print "  -u      build with debugging symbols"
+    print "  -u      build with debugging symbols (requires a debug build of Python on Windows"
     print "  -v dir  where the PyQt .sip files will be installed [default %s]" % opt_pyqtsipdir
     print "  -w      don't suppress compiler output during configuration"
     print "  -y lib  explicitly specify the type of Qt library, either qt, qt-mt, qte, qte-mt or qtmt"
@@ -409,6 +409,7 @@ def create_config(module, template, macros):
     sipconfig.inform("Creating %s..." % module)
 
     content = {
+        "pyqt_config_args":   sys.argv[1:],
         "pyqt_version":       pyqt_version,
         "pyqt_version_str":   pyqt_version_str,
         "pyqt_bin_dir":       opt_pyqtbindir,
@@ -517,7 +518,7 @@ def compile_qt_program(name, define=None, include_dir=None, lib_dir=None, lib=No
 
         try:
             os.wait()
-        except AttributeError:
+        except:
             pass
     else:
         os.system(build)
@@ -557,7 +558,7 @@ def check_qscintilla():
 
             # If we find a snapshot then set a negative version number as a
             # special case.
-            if sciversstr[:8] == "snapshot":
+            if string.find(sciversstr, "snapshot") >= 0:
                 qsci_version = -1
         else:
             sipconfig.inform("The QScintilla library could not be found in %s and so the qtext module will not be built. If QScintilla is installed then use the -o argument to explicitly specify the correct directory." % opt_qscilibdir)
@@ -694,6 +695,10 @@ int main(int argc,char **argv)
 #if !defined(Q_WS_WIN) || QT_VERSION < 0x030000 || defined(QT_NO_STYLE_WINDOWSXP)
     fprintf(fp,"-x Qt_STYLE_WINDOWSXP\\n");
 #endif
+
+#if defined(Q_OS_WIN64)
+    fprintf(fp,"-x Qt_Q_LONG_IS_long\\n");
+#endif
 """ % (name, name))
 
     for feat in flist:
@@ -722,7 +727,7 @@ int main(int argc,char **argv)
     f.close()
 
     # Build the program.
-    exe = compile_qt_program("mkfeatures.cpp", include_dir=sipcfg.py_inc_dir, python=1, debug=opt_debug)
+    exe = compile_qt_program("mkfeatures.cpp", include_dir=sipcfg.py_inc_dir, python=1)
     if not exe:
         sipconfig.error("Unable to build mkfeatures utility.")
 
@@ -825,7 +830,8 @@ def set_sip_flags():
             0x010400: "QScintilla_1_3",
             0x010500: "QScintilla_1_4",
             0x010600: "QScintilla_1_5",
-            0x020000: "QScintilla_1_6"
+            0x010700: "QScintilla_1_6",
+            0x020000: "QScintilla_1_7"
         }
 
         verstag = sipconfig.version_to_sip_tag(qsci_version, qscitags, "QScintilla")
